Type: Package
Package: tinyVAST
Title: Multivariate Spatio-Temporal Models using Structural Equations
Version: 1.6.0
Date: 2026-05-18
Authors@R: c(
    person(c("James", "T."), "Thorson", , "James.Thorson@noaa.gov", 
	   role = c("aut", "cre"),
           comment = c(ORCID = "0000-0001-7415-1010")),
    person(c("Sean", "C."), "Anderson", , "sean@seananderson.ca",
           role = c("aut"),
           comment = c(ORCID = "0000-0001-9563-1937")) 
    )
Description: Fits a wide variety of multivariate spatio-temporal models
    with simultaneous and lagged interactions among variables (including
    vector autoregressive spatio-temporal ('VAST') dynamics)
    for areal, continuous, or network spatial domains.  
    It includes time-variable, space-variable, and space-time-variable 
    interactions using dynamic structural equation models ('DSEM') 
    as expressive interface, and the 'mgcv' package to specify splines 
    via the formula interface.  See Thorson et al. (2025)
    <doi:10.1111/geb.70035> for more details.
License: GPL-3
Depends: R (>= 4.1.0)
Imports: corpcor, fmesher, igraph, Matrix (>= 1.3.0), methods, utils,
        mgcv, sem, sf, sfnetworks, TMB (>= 1.9.17), units, checkmate,
        abind, sdmTMB, dsem (>= 1.6.0), insight, cv, sparseinv, gstat,
        cli, GpGp, GPvecchia
Suggests: ggplot2, knitr, lattice, mvtnorm, pdp, rmarkdown,
        rnaturalearth, rnaturalearthdata, testthat, tweedie,
        viridisLite, visreg, plyr, DHARMa, glmmTMB, tibble, RANN
LinkingTo: RcppEigen, TMB
VignetteBuilder: knitr
Config/testthat/edition: 3
Config/testthat/parallel: true
Encoding: UTF-8
LazyData: true
LazyDataCompression: xz
URL: https://vast-lib.github.io/tinyVAST/
BugReports: https://github.com/vast-lib/tinyVAST/issues/
Config/roxygen2/version: 8.0.0
NeedsCompilation: yes
Packaged: 2026-05-19 00:06:36 UTC; James.Thorson
Author: James T. Thorson [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-7415-1010>),
  Sean C. Anderson [aut] (ORCID: <https://orcid.org/0000-0001-9563-1937>)
Maintainer: James T. Thorson <James.Thorson@noaa.gov>
Repository: CRAN
Date/Publication: 2026-05-19 02:30:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-05-19 05:46:46 UTC; unix
Archs: tinyVAST.so.dSYM
