# Generated by roxygen2: do not edit by hand

S3method(GetResponse,tinyVAST)
S3method(fitted,tinyVAST)
S3method(get_data,tinyVAST)
S3method(logLik,tinyVAST)
S3method(model.frame,tinyVAST)
S3method(plot,nngp_domain)
S3method(predict,tinyVAST)
S3method(print,tinyVAST)
S3method(residuals,tinyVAST)
S3method(simulate,tinyVAST)
S3method(summary,tinyVAST)
S3method(vcov,tinyVAST)
export(add_mesh_covariates)
export(add_predictions)
export(cAIC)
export(conditional_gmrf)
export(delta_gamma)
export(delta_lognormal)
export(deviance_explained)
export(integrate_output)
export(lognormal)
export(make_dsem_ram)
export(make_eof_ram)
export(make_nngp_domain)
export(make_sem_ram)
export(nbinom1)
export(nbinom2)
export(project)
export(reload_model)
export(rmvnorm_prec)
export(rotate_pca)
export(sample_variable)
export(sanity)
export(sfnetwork_evaluator)
export(sfnetwork_mesh)
export(simulate_sfnetwork)
export(spatial_cor)
export(student)
export(term_covariance)
export(tinyVAST)
export(tinyVASTcontrol)
export(tweedie)
import(methods)
importFrom(GPvecchia,order_maxmin_exact)
importFrom(GpGp,find_ordered_nn)
importFrom(Matrix,Cholesky)
importFrom(Matrix,Diagonal)
importFrom(Matrix,Matrix)
importFrom(Matrix,diag)
importFrom(Matrix,mat2triplet)
importFrom(Matrix,solve)
importFrom(Matrix,sparseMatrix)
importFrom(Matrix,t)
importFrom(TMB,MakeADFun)
importFrom(TMB,config)
importFrom(TMB,runSymbolicAnalysis)
importFrom(TMB,sdreport)
importFrom(abind,abind)
importFrom(checkmate,assertClass)
importFrom(checkmate,assertDataFrame)
importFrom(checkmate,assertInteger)
importFrom(checkmate,assertNumeric)
importFrom(cli,cli_abort)
importFrom(cli,cli_alert_danger)
importFrom(cli,cli_alert_info)
importFrom(cli,cli_alert_success)
importFrom(cli,cli_inform)
importFrom(cli,cli_warn)
importFrom(corpcor,pseudoinverse)
importFrom(cv,GetResponse)
importFrom(cv,cv)
importFrom(dsem,make_matrices)
importFrom(fmesher,fm_evaluator)
importFrom(fmesher,fm_fem)
importFrom(fmesher,fm_mesh_2d)
importFrom(igraph,as_adjacency_matrix)
importFrom(igraph,ecount)
importFrom(insight,get_data)
importFrom(insight,get_response)
importFrom(methods,as)
importFrom(methods,is)
importFrom(sdmTMB,lognormal)
importFrom(sdmTMB,nbinom1)
importFrom(sdmTMB,nbinom2)
importFrom(sdmTMB,student)
importFrom(sdmTMB,tweedie)
importFrom(sem,specifyEquations)
importFrom(sem,specifyModel)
importFrom(sf,st_as_sf)
importFrom(sf,st_centroid)
importFrom(sf,st_coordinates)
importFrom(sf,st_crs)
importFrom(sf,st_distance)
importFrom(sf,st_geometry)
importFrom(sf,st_geometry_type)
importFrom(sf,st_length)
importFrom(sf,st_nearest_feature)
importFrom(sf,st_relate)
importFrom(sf,st_within)
importFrom(sfnetworks,activate)
importFrom(sparseinv,Takahashi_Davis)
importFrom(sparseinv,cholPermute)
importFrom(stats,.getXlevels)
importFrom(stats,Gamma)
importFrom(stats,as.formula)
importFrom(stats,binomial)
importFrom(stats,dist)
importFrom(stats,fitted)
importFrom(stats,gaussian)
importFrom(stats,lm)
importFrom(stats,logLik)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,model.offset)
importFrom(stats,model.response)
importFrom(stats,na.omit)
importFrom(stats,na.pass)
importFrom(stats,nlminb)
importFrom(stats,optim)
importFrom(stats,optimHess)
importFrom(stats,pnorm)
importFrom(stats,poisson)
importFrom(stats,predict)
importFrom(stats,rnorm)
importFrom(stats,sd)
importFrom(stats,simulate)
importFrom(stats,terms)
importFrom(stats,update)
importFrom(stats,update.formula)
importFrom(stats,vcov)
importFrom(units,drop_units)
importFrom(utils,capture.output)
importFrom(utils,packageVersion)
useDynLib(tinyVAST, .registration = TRUE)
